@@ -5,7 +5,8 @@ fn main() {
     let collector = create_trace_listener(
         TraceListenerOptions::new()
                 .with_stdout(true)
-                .with_file_path("./simple-example.log", false)
+                .with_thread_ids(true)
+                .with_file_path("./simple-example.log", true)
                 .with_env_filter("[crate-name],[child]"),
     );
 
