@@ -11,10 +11,13 @@ pub mod tracing_macros {
 mod trace;
 pub use trace::Trace;
 
+pub const EMPTY_FIELD: tracing::field::Empty = tracing::field::Empty;
+
 // re-export the filter object
 pub use tracing_subscriber::EnvFilter;
 // re-export the subscriber extensions so `collector.init()` can be called explicitly
 pub use tracing_subscriber::util::SubscriberInitExt;
+pub use tracing::Span;
 
 // export the trace listener utils
 mod utils;
