@@ -2,26 +2,45 @@ use tracing::{info, trace, debug, warn, error, Span};
 use crate::Tracer;
 
 pub struct Trace {
-    pub name: String,
-    pub is_silent: bool,
-    pub trace_span: Span,
-    pub info_span: Span,
-    pub debug_span: Span,
-    pub warn_span: Span,
-    pub error_span: Span,
+    trace_tree_name: &'static str,
+    is_silent: bool,
+    trace_span: Span,
+    info_span: Span,
+    debug_span: Span,
+    warn_span: Span,
+    error_span: Span,
 }
 
 impl std::fmt::Debug for Trace {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         return f.debug_struct("Trace")
-            .field("name", &self.name)
+            .field("name", &self.trace_tree_name)
             .finish();
     }
 }
 
 impl Tracer for Trace {
-    fn name(&self) -> &str {
-        return &self.name;
+    fn trace_tree_name(&self) -> &'static str {
+        return &self.trace_tree_name;
+    }
+
+    fn is_silent(&self) -> bool {
+        return self.is_silent;
+    }
+
+    fn as_silent(mut self, is_silent: bool) -> Box<dyn Tracer> {
+        self.is_silent = is_silent;
+
+        return Box::new(
+            Trace {
+                is_silent,
+                ..self
+            },
+        );
+    }
+
+    fn span(&self) -> &Span {
+        return &self.trace_span;
     }
 
     // fn child(&self, child_name: &'static str) -> Box<dyn Tracer> {
@@ -100,86 +119,61 @@ impl Tracer for Trace {
 }
 
 impl Trace {
-    pub fn as_silent(mut self, is_silent: bool) -> Self {
-        self.is_silent = is_silent;
-
-        return self;
-    }
-
-    pub fn name(&self) -> &str {
-        return Tracer::name(self);
-    }
-
-    pub fn trace(&self, message: &str) -> &dyn Tracer {
-        return Tracer::trace(self, message);
-    }
-
-    pub fn debug(&self, message: &str) -> &dyn Tracer {
-        return Tracer::debug(self, message);
-    }
-
-    pub fn info(&self, message: &str) -> &dyn Tracer {
-        return Tracer::info(self, message);
-
-    }
-
-    pub fn warn(&self, message: &str) -> &dyn Tracer {
-        return Tracer::warn(self, message);
-
-    }
-
-    pub fn error(&self, message: &str) -> &dyn Tracer {
-        return Tracer::error(self, message);
-
-    }
-
     pub fn new(
-        name: String,
+        name: &'static str,
         is_silent: bool,
         trace_span: Span,
         info_span: Span,
         debug_span: Span,
         warn_span: Span,
         error_span: Span,
-    ) -> Self {
-        return Trace {
-            is_silent,
-            trace_span,
-            info_span,
-            debug_span,
-            warn_span,
-            error_span,
-            name,
-        };
+    ) -> Box<dyn Tracer> {
+        return Box::new(
+            Trace {
+                is_silent,
+                trace_span,
+                info_span,
+                debug_span,
+                warn_span,
+                error_span,
+                trace_tree_name: name,
+            },
+        );
     }
 }
 
 #[macro_export]
 macro_rules! create_trace {
     ($name:expr) => {
-        Trace::new(
-            ($name).to_string(),
-            false,
-            cs_trace::tracing_macros::trace_span!($name),
-            cs_trace::tracing_macros::info_span!($name),
-            cs_trace::tracing_macros::debug_span!($name),
-            cs_trace::tracing_macros::warn_span!($name),
-            cs_trace::tracing_macros::error_span!($name),
-        );
+        {
+            cs_trace::Trace::new(
+                $name,
+                false,
+                cs_trace::tracing_macros::trace_span!($name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::info_span!($name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::debug_span!($name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::warn_span!($name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::error_span!($name, cs_trace = cs_trace::EMPTY_FIELD),
+            )
+        };
     };
 }
 
 #[macro_export]
 macro_rules! child {
     ($parent_trace:ident, $name:expr) => {
-        Trace::new(
-            ($name).to_string(),
-            false,
-            cs_trace::tracing_macros::trace_span!(parent: &$parent_trace.trace_span, $name),
-            cs_trace::tracing_macros::info_span!(parent: &$parent_trace.info_span, $name),
-            cs_trace::tracing_macros::debug_span!(parent: &$parent_trace.debug_span, $name),
-            cs_trace::tracing_macros::warn_span!(parent: &$parent_trace.warn_span, $name),
-            cs_trace::tracing_macros::error_span!(parent: &$parent_trace.error_span, $name),
-        );
+        {
+            let parent_span = $parent_trace.span();
+
+            cs_trace::Trace::new(
+                $parent_trace.trace_tree_name(),
+                $parent_trace.is_silent(),
+                cs_trace::tracing_macros::trace_span!(parent: parent_span, $name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::info_span!(parent: parent_span, $name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::debug_span!(parent: parent_span, $name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::warn_span!(parent: parent_span, $name, cs_trace = cs_trace::EMPTY_FIELD),
+                cs_trace::tracing_macros::error_span!(parent: parent_span, $name, cs_trace = cs_trace::EMPTY_FIELD),
+            )
+        };
     };
 }
