@@ -8,6 +8,8 @@ pub struct TraceListenerOptions {
     level: Level,
     is_stdout: bool,
     cleanup_file: bool,
+    include_thread_ids: bool,
+    include_thread_names: bool,
     file_path: String,
     filter: EnvFilter,
 }
@@ -18,6 +20,8 @@ impl Default for TraceListenerOptions {
             level: Level::TRACE,
             is_stdout: true,
             cleanup_file: false,
+            include_thread_ids: false,
+            include_thread_names: false,
             file_path: String::new(),
             filter: EnvFilter::default(),
         };
@@ -43,6 +47,14 @@ impl TraceListenerOptions {
         return TraceListenerOptions { file_path, cleanup_file: cleanup_file, ..self };
     }
 
+    pub fn with_thread_names(self, include_thread_names: bool) -> Self {
+        return TraceListenerOptions { include_thread_names, ..self };
+    }
+
+    pub fn with_thread_ids(self, include_thread_ids: bool) -> Self {
+        return TraceListenerOptions { include_thread_ids, ..self };
+    }
+
     pub fn with_env_filter(self, filter: impl Into<EnvFilter>) -> Self {
         let filter = filter.into();
 
@@ -58,6 +70,8 @@ pub fn create_trace_listener(
         file_path,
         is_stdout,
         cleanup_file,
+        include_thread_names,
+        include_thread_ids,
         filter,
         ..
     } = options;
@@ -85,7 +99,8 @@ pub fn create_trace_listener(
         // are called from within the trace create
         .with_target(false)
         // include thread name
-        .with_thread_names(true)
+        .with_thread_ids(include_thread_ids)
+        .with_thread_names(include_thread_names)
         // setup writers based on options
         .with_writer(make_composite_writer)
         .with_env_filter(filter)
