@@ -11,7 +11,7 @@ pub struct FileWriter {
 impl FileWriter {
     pub fn new<T: AsRef<str> + ToString>(
         file_path: T,
-        is_cleanup_file: bool,
+        cleanup_file: bool,
     ) -> Box<dyn Write + Send + Sync> {
         let file_path = file_path.to_string();
 
@@ -33,8 +33,8 @@ impl FileWriter {
         let file_handle = OpenOptions::new()
             .create(true)
             .write(true)
-            // .truncate(is_cleanup_file)
-            .append(!is_cleanup_file)
+            .truncate(cleanup_file)
+            .append(!cleanup_file)
             .open(&file_path)
             .expect(
                 &format!("Cannot open file at [{}].", &file_path),
