@@ -4,4 +4,4 @@ mod composite_writer;
 
 pub use noop_writer::NoopWriter;
 pub use file_writer::FileWriter;
-pub use composite_writer::CompositeWriter;
+pub use composite_writer::{CompositeWriter, MakeCompositeWriter};
