@@ -1,7 +1,7 @@
 
 use std::thread;
 
-use cs_trace::{Trace, create_trace, child};
+use cs_trace::{create_trace, child};
 use cs_utils::futures::wait;
 use tokio::try_join;
 
